@@ -4,7 +4,6 @@ from datetime import datetime
 from tkinter.messagebox import showerror, askokcancel
 from tkinter import *
 from threading import Lock, Thread
-from inspect import isclass
 
 import os
 import logging
@@ -73,7 +72,8 @@ class LogHandle(object):
             self.__gui_console = None
         elif self.__gui_console and turn_off:
             self.__gui_console = None
-        elif gui_obj and isclass(gui_obj) and hasattr(gui_obj, "print_gui"):
+        elif gui_obj and hasattr(gui_obj, "print_gui") and hasattr(gui_obj, "log_setup"):
+            gui_obj.log_setup(log_class=self)
             self.__gui_console = gui_obj
         else:
             self.__gui_console = GUIConsole(parent=self, title=title)
@@ -141,7 +141,7 @@ class GUIConsole(Toplevel):
         self.__build()
         self.__start_idle()
 
-    def __cleanup(self):
+    def __cleanup(self, event):
         self.__parent.gc = None
 
     def __start_idle(self):
